@@ -25,16 +25,16 @@
 // DEALINGS IN THE SOFTWARE.
 
 #![cfg(test)]
-use crate::types::{
-	traits::{Client, SubscriptionClient},
-	v2::{ErrorCode, ErrorObject, ParamsSer, RpcError},
-	Error, Subscription,
-};
+use crate::types::error::{ErrorCode, ErrorObject, ErrorResponse};
+use crate::types::ParamsSer;
 use crate::WsClientBuilder;
+use jsonrpsee_core::client::Subscription;
+use jsonrpsee_core::client::{ClientT, SubscriptionClientT};
+use jsonrpsee_core::rpc_params;
+use jsonrpsee_core::Error;
 use jsonrpsee_test_utils::helpers::*;
 use jsonrpsee_test_utils::mocks::{Id, WebSocketTestServer};
 use jsonrpsee_test_utils::TimeoutFutureExt;
-use jsonrpsee_utils::rpc_params;
 use serde_json::Value as JsonValue;
 
 #[tokio::test]
@@ -173,18 +173,18 @@ async fn notification_without_polling_doesnt_make_client_unuseable() {
 
 	// Capacity is `num_sender` + `capacity`
 	for _ in 0..5 {
-		assert!(nh.next().with_default_timeout().await.unwrap().unwrap().is_some());
+		assert!(nh.next().with_default_timeout().await.unwrap().unwrap().is_ok());
 	}
 
 	// NOTE: this is now unuseable and unregistered.
-	assert!(nh.next().with_default_timeout().await.unwrap().unwrap().is_none());
+	assert!(nh.next().with_default_timeout().await.unwrap().is_none());
 
 	// The same subscription should be possible to register again.
 	let mut other_nh: Subscription<String> =
 		client.subscribe_to_method("test").with_default_timeout().await.unwrap().unwrap();
 
 	// check that the new subscription works.
-	assert!(other_nh.next().with_default_timeout().await.unwrap().unwrap().is_some());
+	assert!(other_nh.next().with_default_timeout().await.unwrap().unwrap().is_ok());
 	assert!(client.is_connected());
 }
 
@@ -250,7 +250,7 @@ async fn run_request_with_response(response: String) -> Result<JsonValue, Error>
 fn assert_error_response(err: Error, exp: ErrorObject) {
 	match &err {
 		Error::Request(e) => {
-			let this: RpcError = serde_json::from_str(e).unwrap();
+			let this: ErrorResponse = serde_json::from_str(e).unwrap();
 			assert_eq!(this.error, exp);
 		}
 		e => panic!("Expected error: \"{}\", got: {:?}", err, e),
